@@ -1,5 +1,5 @@
 package Object::eBay;
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 use Class::Std; {
     use warnings;
@@ -240,7 +240,7 @@ Object::eBay - Object-oriented interface to the eBay API
  
 =head1 VERSION
  
-This documentation refers to Object::eBay version 0.0.2
+This documentation refers to Object::eBay version 0.0.3
  
  
 =head1 SYNOPSIS
@@ -248,6 +248,7 @@ This documentation refers to Object::eBay version 0.0.2
     use Object::eBay;
     my $ebay = # ... create a Net::eBay object ...
     Object::eBay->init($ebay);
+    
     my $item = Object::eBay::Item->new({ item_id => 12345678 });
     my $title = $item->title();
     my $price = $item->selling_status->current_price();
@@ -255,11 +256,12 @@ This documentation refers to Object::eBay version 0.0.2
 
 =head1 DESCRIPTION
  
-Object::eBay provides an object-oriented interface to the eBay API.
-Objects are created to represent entities dealing with eBay such as items,
-users, etc.  You won't want to create objects of the class L<Object::eBay> but
-rather of its subclasses such as: L<Object::eBay::Item> or
-L<Object::eBay::User>.
+Object::eBay provides an object-oriented interface to the eBay API.  Objects
+are created to represent entities dealing with eBay such as items, users, etc.
+You won't want to create objects of the class L<Object::eBay> but rather of
+its subclasses such as: L<Object::eBay::Item> or L<Object::eBay::User>.  eBay
+API calls are processed using the Perl module L<Net::eBay> (available from
+CPAN or from L<http://www.net-ebay.org>).
 
 L<Object::eBay> follows some simple rules to make the names of eBay API
 objects more "Perlish."  Namely, for packages, eBay's camelcase is retained.
@@ -472,6 +474,9 @@ None known.
 
 =head1 HELPING OUT
 
+The latest source code for Object-eBay is available with git from
+L<git://ndrix.com/Object-eBay>
+
 If you have any patches, please submit them through the RT bug tracking
 interface see L</BUGS AND LIMITATIONS>.  Right now, the most needed assistance
 is with filling out the objects and associated accessor methods.  To create a
@@ -525,6 +530,10 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Object-eBay>
 
 L<http://search.cpan.org/dist/Object-eBay>
 
+=item * Paid Support and Development
+
+L<http://www.ndrix.com>
+
 =back
 
 =head1 SEE ALSO
@@ -543,15 +552,17 @@ L<http://search.cpan.org/dist/Object-eBay>
 
 =head1 ACKNOWLEDGEMENTS
 
+JJ Games for sponsoring the original development L<http://www.jjgames.com>.
+
 Igor Chudov for writing Net::eBay.
 
 =head1 AUTHOR
 
-Michael Hendricks  <michael@ndrix.org>
+Michael Hendricks  <michael@ndrix.com>
 
 =head1 LICENSE AND COPYRIGHT
  
-Copyright (c) 2006 Michael Hendricks (<michael@ndrix.org>). All rights
+Copyright (c) 2006-2007 Michael Hendricks (<michael@ndrix.com>). All rights
 reserved.
 
 This program is free software; you can redistribute it and/or modify it
